@@ -39,21 +39,31 @@ define('ONMS_U', "OnMouseUp");
 define('ONMS_D', "OnMouseDown");
 define('ONMS_C', "OnClick");
 define('ONK_D', "OnKeyDown");
+define('ALI', "align");
+define('CEN', "center");
 
 //------------------- Controler ----------------------
 
-//print_r($_SERVER);//exit();
+//print_r($_POST);//exit();
+//print_r($_params);
+$_nbMois=litParam('nbMois');
+$_mois=litParam('premMois');
+$_nbMoisTotal=litParam('nbMoisTotal');
 
-// --- sauvegarde des paramètres ---
+//si pas encore défini dans la base, on le fait
+if ($_nbMois===false) {$_nbMois=10; ecritParam('nbMois',$_nbMois);}
+if ($_mois===false) {$_mois=9; ecritParam('premMois',$_mois);}
+if ($_nbMoisTotal===false) {$_nbMoisTotal=12; ecritParam('nbMoisTotal',$_nbMoisTotal);}
 
-if (isset($_GET)) {
-	$_annee=$_GET['annee'];
-	$_mois=$_GET['mois'];
-	$_nbMois=$_GET['nbMois'];
-	if ($_GET['mode']=="edition") $edition=true; else $edition=false; //edition ou affichage (par défaut)
-}
+//prise en compte d'éventuel paramètre en ligne de commande	
+if (isset($_GET['annee'])) $_annee=$_GET['annee'];
+if (isset($_GET['mois'])) $_mois=$_GET['mois'];
+if (isset($_GET['nbMois'])) $_nbMois=$_GET['nbMois'];
+if (isset($_GET['nbMoisTotal'])) $_nbMoisTotal=$_GET['nbMoisTotal'];
+if ($_GET['mode']=="edition") $edition=true; else $edition=false; //edition ou affichage (par défaut)
 
 $tabDate=getdate();
+//print_r($tabDate);
 
 if ($_mois!="") $moisAff=$_mois;
 else { // si pas de mois défini
@@ -68,11 +78,27 @@ if ($_nbMois!="") $nbMoisAff=$_nbMois;
 else { // si le nb de mois n'est pas défini
 	$nbMoisAff=10;
 }
+if ($_nbMoisTotal!="") $nbMoisTotal=$_nbMoisTotal;
+else { // si le nb de mois total n'est pas défini
+	$nbMoisTotal=12;
+}
 if ($nbMoisAff>12) $nbMoisAff=12; //limite à 12 mois
 if ($anneeAff<1970) $anneeAff=1970; //limite l'année à 1970 au minimum
+//echo ' '.$nbMoisAff.'>'.$nbMoisTotal.' ';
+if ($nbMoisAff>$nbMoisTotal) $nbMoisTotal=$nbMoisAff; //limite au minimum au nombre de mois affichés
 
-
-if (isset($_POST[lig_1])) { //on enregistre un calendrier
+// --- sauvegarde des paramètres ---
+$changeMois=false;
+if (isset($_POST['valMois'])) { //on change la config du nombre de mois
+	$changeMois=true;
+	$_nbMois=$nbMoisAff=$_POST['selNbMois'];
+	$_mois=$moisAff=$_POST['selPremMois'];
+	$_nbMoisTotal=$nbMoisTotal=$_POST['selNbMoisTotal'];
+	ecritParam('nbMois',$_POST['selNbMois']);
+	ecritParam('premMois',$_POST['selPremMois']);
+	ecritParam('nbMoisTotal',$_POST['selNbMoisTotal']);
+	//echo ($_POST['selNbMois'].'/'.$_POST['selPremMois']);
+} else if (isset($_POST['sauveTab_x'])) { //on enregistre un calendrier
 	foreach($_POST as $_key=>$_val) { //on prépare le tableau pour l'enregistrement
 		if (substr($_key, 0,4)=="lig_") {
 			$_numLig=substr($_key,4);
@@ -84,9 +110,22 @@ if (isset($_POST[lig_1])) { //on enregistre un calendrier
 }
 
 if (isset($_GET['mode'])) {
-	if (($_GET['mode']=='supprAnnee') && isset($_GET['annee'])) supprimeCalendrierAnnee($_GET['annee']);
+	//if (($_GET['mode']=='supprAnnee') && isset($_GET['annee'])) supprimeCalendrierAnnee($_GET['annee']);
+	if (($_GET['mode']=='supprAnnee') && isset($_GET['annee'])) supprimeCalendrier($anneeAff, $moisAff, $nbMoisAff);
 }
 
+$anneePrec=$anneeAff;
+$moisPrec=$moisAff-$nbMoisTotal;
+if ($moisPrec<1) {$moisPrec+=12; $anneePrec--;}
+$lienPrec="annee=$anneePrec&mois=$moisPrec";
+$anneeSuiv=$anneeAff;
+$moisSuiv=$moisAff+$nbMoisTotal;
+if ($moisSuiv>12) {$moisSuiv-=12; $anneeSuiv++;}
+$lienSuiv="annee=$anneeSuiv&mois=$moisSuiv";
+
+$affAnnees=$anneeAff;
+if ($moisAff+$nbMoisAff-1>12) $affAnnees.='/'.($anneeAff+1);
+
 //définition du mode Edition si reception de la variable modeEdition en POST
 $modeEdition=false;
 $medit=true; //force le mode édition             $medit=false;
@@ -98,11 +137,18 @@ if (isset($_GET['mode'])) if ($_GET['mode']=="ed" || $forceModeEd) $medit=true;
 //------------------- View -------------------------
 headerPage();
 enteteHTML($titrePage,array("./jquery/jquery.min.js",
-														"./jquery/js/jquery-ui.min.js", //jquery-ui-1.8.17.custom.min.js", //jquery-ui-1.10.4.custom.min.js", 
-														"./incAppli/calend.js",
-														"./jquery/css/smoothness/jquery-ui.min.css", //jquery-ui-1.10.4.custom.min.css", //  custom-theme2/jquery-ui-1.8.17.custom.css",
-														"./inc/scribe.css","./inc/tabHTML.css","./incAppli/calend.css","./inc/onglets.css","./inc/droits.css","./inc/collecParam.css",
-														"./images/pFavicon.ico.png"));
+                            "./jquery/js/jquery-ui.min.js",
+                            "./bootstrap/css/bootstrap.min.css",
+                            "./bootstrap/js/bootstrap.min.js",                             
+                            "./incAppli/calend.js",
+                            "./jquery/css/smoothness/jquery-ui.min.css",
+                            "./inc/scribe.css",
+                            "./inc/tabHTML.css",
+                            "./incAppli/calend.css",
+                            "./inc/onglets.css",
+                            "./inc/droits.css",
+                            "./inc/collecParam.css",
+                            "./images/pFavicon.ico.png"));
 
 
 //init javascript du tableau des dates
@@ -350,9 +396,9 @@ echo '<td id="_dskSauve" width="26" align="left">';
 if ($modeEdition) echo '<image src="./images/disketteG.gif" />'; else echo '&nbsp;';
 echo '</td>'.CRLF;
 echo '<td id="_txtSauve" width="224" align="left">'.'&nbsp;'.'</td>'.CRLF;
-echo '<td width="200" align="center"><input type="button" value="<<" onClick="window.location=\'calend.php?'.$phModeEdit.'annee='.($anneeAff-1).'\'">'.'&nbsp;'.'&nbsp;'.CRLF;
-echo '<b>'.$anneeAff.' / '.($anneeAff+1).'</b>'.'&nbsp;'.'&nbsp;'.CRLF;
-echo '<input type="button" value=">>" onClick="window.location=\'calend.php?'.$phModeEdit.'annee='.($anneeAff+1).'\'"></td>'.CRLF;
+echo '<td width="200" align="center"><input type="button" value="<<" onClick="window.location=\'calend.php?'.$phModeEdit.$lienPrec.'\'">'.'&nbsp;'.'&nbsp;'.CRLF;
+echo '<b>'.$affAnnees.'</b>'.'&nbsp;'.'&nbsp;'.CRLF;
+echo '<input type="button" value=">>" onClick="window.location=\'calend.php?'.$phModeEdit.$lienSuiv.'\'"></td>'.CRLF;
 echo '<td align="right"></td>'.CRLF; //width="250" <a href="'.$codeJSRetour.'"><image src="../images/sortie.gif" border="0"'.' title="'.$txtRetour.'" />
 echo '</tr></table>'.CRLF;
 
@@ -367,8 +413,63 @@ if ($modeEdition) {
 	<script language="JavaScript"></script>
 	<a href="#" onClick="placeWeekend();return false">Placer les week-end</a>
 	<a href="#" onClick="placeJoursFeries();return false" style="margin:0 0 0 50px">Placer les jours fériés</a>
-	<a href="#" onClick="$('#importVacances').slideToggle();return false;" style="margin:0 0 0 50px">Placer les vacances</a> <?php echo iconeAide(1);?>
+	<a href="#" onClick="$('#importVacances').slideToggle();if ($('#changeConfigMois').css('display')!='none') $('#changeConfigMois').slideToggle();return false;" style="margin:0 0 0 50px">Placer les vacances</a> <?php echo iconeAide(1);?>
+		
+	<a href="#" onClick="$('#changeConfigMois').slideToggle();if ($('#importVacances').css('display')!='none') $('#importVacances').slideToggle();return false;" style="margin:0 0 0 50px">Changer la configuration des mois</a>
+	
+	<div id="changeConfigMois" style="display:none">
+		<i><b>Changer la configuration des mois affichés dans le calendrier</b></i><br/>
+		<!--<form action="./calend.php" method="POST"> -->
+		<div style="margin:10px 0 0 0">
+			nombre de mois affichés : <select  style="padding:0px;margin:0px" name="selNbMois">
+			<option value="1"<?php echo ($nbMoisAff==1?" SELECTED":""); ?> >1</option>
+			<option value="2"<?php echo ($nbMoisAff==2?" SELECTED":""); ?> >2</option>
+			<option value="3"<?php echo ($nbMoisAff==3?" SELECTED":""); ?> >3</option>
+			<option value="4"<?php echo ($nbMoisAff==4?" SELECTED":""); ?> >4</option>
+			<option value="5"<?php echo ($nbMoisAff==5?" SELECTED":""); ?> >5</option>
+			<option value="6"<?php echo ($nbMoisAff==6?" SELECTED":""); ?> >6</option>
+			<option value="7"<?php echo ($nbMoisAff==7?" SELECTED":""); ?> >7</option>
+			<option value="8"<?php echo ($nbMoisAff==8?" SELECTED":""); ?> >8</option>
+			<option value="9"<?php echo ($nbMoisAff==9?" SELECTED":""); ?> >9</option>
+			<option value="10"<?php echo ($nbMoisAff==10?" SELECTED":""); ?> >10</option>
+			<option value="11"<?php echo ($nbMoisAff==11?" SELECTED":""); ?> >11</option>
+			<option value="12"<?php echo ($nbMoisAff==12?" SELECTED":""); ?> >12</option>
+		</select>
+		<span style="margin:0 0 0 50px"></span>premier mois affiché : <select name="selPremMois">
+			<option value="1"<?php echo ($moisAff==1?" SELECTED":""); ?> >Janvier</option>
+			<option value="2"<?php echo ($moisAff==2?" SELECTED":""); ?> >Février</option>
+			<option value="3"<?php echo ($moisAff==3?" SELECTED":""); ?> >Mars</option>
+			<option value="4"<?php echo ($moisAff==4?" SELECTED":""); ?> >Avril</option>
+			<option value="5"<?php echo ($moisAff==5?" SELECTED":""); ?> >Mai</option>
+			<option value="6"<?php echo ($moisAff==6?" SELECTED":""); ?> >Juin</option>
+			<option value="7"<?php echo ($moisAff==7?" SELECTED":""); ?> >Juillet</option>
+			<option value="8"<?php echo ($moisAff==8?" SELECTED":""); ?> >Août</option>
+			<option value="9"<?php echo ($moisAff==9?" SELECTED":""); ?> >Septembre</option>
+			<option value="10"<?php echo ($moisAff==10?" SELECTED":""); ?> >Octobre</option>
+			<option value="11"<?php echo ($moisAff==11?" SELECTED":""); ?> >Novembre</option>
+			<option value="12"<?php echo ($moisAff==12?" SELECTED":""); ?> >Décembre</option>
+		</select>
+		<span style="margin:0 0 0 50px"></span>durée de la période complète : <select  style="padding:0px;margin:0px" name="selNbMoisTotal">
+			<option value="1"<?php echo ($nbMoisTotal==1?" SELECTED":""); ?> >1</option>
+			<option value="2"<?php echo ($nbMoisTotal==2?" SELECTED":""); ?> >2</option>
+			<option value="3"<?php echo ($nbMoisTotal==3?" SELECTED":""); ?> >3</option>
+			<option value="4"<?php echo ($nbMoisTotal==4?" SELECTED":""); ?> >4</option>
+			<option value="5"<?php echo ($nbMoisTotal==5?" SELECTED":""); ?> >5</option>
+			<option value="6"<?php echo ($nbMoisTotal==6?" SELECTED":""); ?> >6</option>
+			<option value="7"<?php echo ($nbMoisTotal==7?" SELECTED":""); ?> >7</option>
+			<option value="8"<?php echo ($nbMoisTotal==8?" SELECTED":""); ?> >8</option>
+			<option value="9"<?php echo ($nbMoisTotal==9?" SELECTED":""); ?> >9</option>
+			<option value="10"<?php echo ($nbMoisTotal==10?" SELECTED":""); ?> >10</option>
+			<option value="11"<?php echo ($nbMoisTotal==11?" SELECTED":""); ?> >11</option>
+			<option value="12"<?php echo ($nbMoisTotal==12?" SELECTED":""); ?> >12</option>
+		</select>
+		<input type="submit" value="Valider" name="valMois" style="margin:0 0 0 50px"/>
+		</div>
+		<!--</form>-->
+	</div>
+		
 	<div id="importVacances" style="display:none"><?php echo $liensImportVacances;?></div>
+	
 	<div style="margin:30px 0 0 0;padding:10px;border:1px SOLID #456;width:800px;background:#789	"><b><i>Sélectionner une légende et appliquer la aux dates souhaitées dans le tableau en les cliquant</i></b><br/><br/>
 <?php
 }
