@@ -13,7 +13,7 @@
 ---------------------------------------------*/
 function creeNouvGrp($nomGrp,$details) {
 	global $mysqli;
-	
+
 	if (trim($nomGrp)=="") return "Nom du groupe vide !";
 	if ($res=$mysqli->query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomGrp'")) {
 		if ($res->num_rows==0) {//le nom n'existe pas encore - on créé le groupe
@@ -33,7 +33,7 @@ function creeNouvGrp($nomGrp,$details) {
 ---------------------------------------------*/
 function recupGrp($choix=0) {
 	global $mysqli;
-	
+
 	if ($choix==0) $leChoix1=$leChoix2='1';
 	else {
 		$leChoix1='groupe_ID='.$choix;
@@ -64,7 +64,7 @@ function recupGrp($choix=0) {
 ---------------------------------------------*/
 function recupCompoGrp($idGrp) {
 	global $mysqli;
-	
+
 	$tMach=array();
 	if ($res=$mysqli->query("SELECT es_machines.nom,machine_ID FROM es_machines,es_grp_machines WHERE machine_ID=ID_machine AND groupe_ID='".$idGrp."' ORDER BY es_machines.nom")) {
 		while (list($_nomM,$_machID)=$res->fetch_row()) {
@@ -84,7 +84,7 @@ function recupCompoGrp($idGrp) {
 ---------------------------------------------*/
 function recupMachines($idMach=0) {
 	global $mysqli;
-	
+
 	if ($idMach==0) $choixMachine='1';
 	else $choixMachine="ID_machine=$idMach";
 	$tMach=array();
@@ -107,7 +107,7 @@ function recupMachines($idMach=0) {
 
 function ajouteMachinesGroupe($idGroupe,$idMach){
 	global $mysqli;
-	
+
 	if (!is_array($idMach)) $idMach=array($idMach);
 	if (count($idMach)>0) foreach ($idMach as $_ajoutMachine) {
 		$query="INSERT INTO es_grp_machines SET groupe_ID='$idGroupe' , machine_ID='$_ajoutMachine'";
@@ -127,7 +127,7 @@ function ajouteMachinesGroupe($idGroupe,$idMach){
 
 function supprimeMachinesGroupe($idGroupe,$idMach){
 	global $mysqli;
-	
+
 	if (!is_array($idMach)) $idMach=array($idMach);
 	if (count($idMach)>0) foreach ($idMach as $_ajoutMachine) {
 		$query="DELETE FROM es_grp_machines WHERE groupe_ID='$idGroupe' AND machine_ID='$_ajoutMachine'";
@@ -146,7 +146,7 @@ function supprimeMachinesGroupe($idGroupe,$idMach){
 ---------------------------------------------*/
 function majNomGroupe($choixG,$nomG,$detailsG) {
 	global $mysqli;
-	
+
 	if ($res=$mysqli->query("SELECT nom FROM es_groupes WHERE nom LIKE '$nomG'")) {
 		if ($res->num_rows==0) {//le nom n'existe pas encore - on créé le groupe
 			$query="UPDATE es_groupes SET nom='$nomG',details='$detailsG' WHERE ID_groupe='$choixG'";
@@ -167,7 +167,7 @@ function majNomGroupe($choixG,$nomG,$detailsG) {
 ---------------------------------------------*/
 function suppGrp($choixG) {
 	global $mysqli;
-	
+
 	$mysqli->query("DELETE FROM es_grp_machines WHERE groupe_ID=".$choixG);
 	$mysqli->query("DELETE FROM es_groupes WHERE ID_groupe=".$choixG);
 }
@@ -319,10 +319,11 @@ function litListe($nomFic,$indice) {
 //affichage de la liste des machines à ne pas arrêter
 function afficheListe($tListe) {
 	//$tListe=explode(PHP_EOL,$nomliste);
+	$tL = array();
 	if (is_array($tListe)) foreach ($tListe as $_lig) {
 		if (trim($_lig)!="") $tL[]=trim($_lig);
 	}
-	if ($tL[0]=="") {
+	if (count($tL)== 0) {
 		return "Toutes les stations vont recevoir l'ordre de s'arrêter";
 	} else {
 		return implode(", ", $tL);
@@ -330,62 +331,83 @@ function afficheListe($tListe) {
 }
 
 //lecture du fichier copie_machines.db pour menu déroulant liste noms stations
-function listeStations($fic,$stationselect) {	
+function listeStations($fic,$stationselect) {
+	$tL = array();
 	if (is_array($stationselect)) foreach ($stationselect as $_lig) {
-		if (trim($_lig)!="") $tL[]=trim($_lig);
+                if (trim($_lig)!="") $tL[]=trim($_lig);
 	}
-	
+
 	//si le fichier copie_machine.db n'existe pas ou qu'il est vide, on sort...
 	if (!file_exists($fic) || filesize($fic) == 0) {
 		echo '<option disabled="1">aucune station trouvée...</option>';
 		return;
 	}
-	
+
 	$id_fichier = fopen($fic,"r");
 	$contenu = fread($id_fichier, filesize($fic));
 	fclose($id_fichier);
+
 	$lignes = explode(PHP_EOL, $contenu);
+	//print_r($lignes);
 	foreach ($lignes as $ligne) {
 		if (trim($ligne)=="") continue;
 		$tabligne = explode(";",$ligne);
+		//print_r($tabligne);
+		/// V2.4.7 - OH - correction affichage lignes vides pour les entrées de copie_machines.db incomplètes
 		if (count($tabligne)==4) { //scribe <= 2.3
 			if (trim($tabligne[1])=="" || trim($tabligne[3])=="" || trim(strtolower($tabligne[3]))=="none") { //pb adresse IP ou adresse MAC
-				$nomsPb[] = $tabligne[0];
-			}
+				$noms[] = $nomsPb[] = $tabligne[0]." (adresse inconnue)";
+			} else $noms[] = $tabligne[0];
+			$noms[] = $tabligne[0];
 		} else { //scribe 2.5
-			if (trim($tabligne[1])=="") { //pb adresse IP ou adresse MAC
-				$nomsPb[] = $tabligne[0];
+			if (trim($tabligne[0])=="") { //pb nom
+				$noms[] = $nomsPb[] = "(nom inconnu - ".$tabligne[1].")";
+				//$noms[] = "(nom inconnu - ".$tabligne[1].")";
 			}
+			else if (trim($tabligne[2])=="") { //pb adresse MAC
+				$noms[] = $nomsPb[] = $tabligne[0].'(adresse MAC inconnue)';
+			}
+			else if (trim($tabligne[1])=="") { //pb adresse IP
+				$noms[] = $nomsPb[] = $tabligne[0].'(adresse IP inconnue)';
+			}
+			else {
+				$noms[] = $tabligne[0];
+				$nomsPb = [];
+		    }
+
 		}
-		$noms[] = $tabligne[0];
-		
+		//$noms[] = $tabligne[0];
+
 		if (isset($noms)) usort($noms, "strcasecmp");
 	}
-	foreach ($noms as $nom) {
-		$desac=$txtPb="";
-		if (in_array($nom, $nomsPb)) {
-			$desac=" disabled";
-			$txtPb=" (adresse inconnue)";
-		}
-		if (in_array($nom, $tL)) {
-			echo '<option selected="selected"'.$desac.'>'.$nom.$txtPb.'</option>';
-		} else {
-			echo '<option'.$desac.'>'.$nom.$txtPb.'</option>';
-		}
+    if(isset($noms)) {
+	    foreach ($noms as $nom) {
+	    	$desac=$txtPb="";
+	    	if (in_array($nom, $nomsPb)) {
+	    		$desac=" disabled";
+	    		//$txtPb=" (adresse inconnue)";
+	    	}
+	    	if (in_array($nom, $tL)) {
+	    		echo '<option selected="selected"'.$desac.'>'.$nom.$txtPb.'</option>';
+	    	} else {
+	    		echo '<option'.$desac.'>'.$nom.$txtPb.'</option>';
+	    	}
+	    }
 	}
+	/// V2.4.7 - OH
 }
 
 //modification du fichier ecoStations.txt
 function ecritFicEcoStations($hor1, $hor2, $liste1, $liste2) {
 	global $ficEcoStations;
-	
+
 	if (is_array($liste1)) foreach ($liste1 as $_lig1) {
 		if (trim($_lig1)!="") $tL1[]=trim($_lig1);
 	}
 	if (is_array($tL1)) foreach ($tL1 as $_lig1) {
 		$cont1.=$_lig1."\n";
 	}
-	
+
 	if (is_array($liste2)) foreach ($liste2 as $_lig2) {
 		if (trim($_lig2)!="") $tL2[]=trim($_lig2);
 	}
@@ -410,7 +432,7 @@ $cont2";
 //modification du fichier ecoStations_start.txt
 function ecritFicEcoStationstart($hor_start, $jour_start, $tListe, $numlignemodif) {
 	global $ficEcoStationstart;
-	
+
 	//formatage de la liste de stations
 	if (is_array($tListe)) foreach ($tListe as $_lig) {
 		if (trim($_lig)!="") $tL[]=trim($_lig);
@@ -422,13 +444,13 @@ function ecritFicEcoStationstart($hor_start, $jour_start, $tListe, $numlignemodi
 		$fp = fopen($ficEcoStationstart, 'r');
 		$contenu = fread($fp, filesize($ficEcoStationstart));
 		fclose($fp);
- 
+
 		$contenu = explode(PHP_EOL, $contenu);
 		$contenu[$numlignemodif] = "$hor_start|$jour_start|$liste_ligne";
 		$contenu = implode(PHP_EOL, $contenu);
 		$fp = fopen($ficEcoStationstart, 'w');
 		fwrite($fp, $contenu);
-		fclose($fp);	
+		fclose($fp);
 	//création d'une nouvelle ligne
 	} else {
 		//si le fichier n'existe pas
@@ -453,18 +475,18 @@ $hor_start|$jour_start|$liste_ligne";
 //suppression d'une ligne dans le fichier ecoStations_start.txt
 function supprLigneEcoStationstart($numligne,$peda_dmz,$_ip) {
 	global $ficEcoStationstart;
-	
+
 	if($numligne!=0) {// on ne supprime pas l'entête du fichier ie la ligne 0.
 		$fp = fopen($ficEcoStationstart, 'r');
 		$contenu = fread($fp, filesize($ficEcoStationstart));
 		fclose($fp);
- 		
+
 		$contenu = explode(PHP_EOL, $contenu); // PHP_EOL contient le saut à la ligne utilisé sur le serveur (\n linux, \r\n windows ou \r Macintosh
 		foreach($numligne as $val) {
 			unset($contenu[$val]); // On supprime la ou les lignes
 		}
 		$contenu = array_values($contenu); // Ré-indexe l'array
-    
+
 		if(count($contenu)!=1) {//s'il reste plus que la ligne d'entête, on reconstruit le tout et on l'écrit
 			$contenu = implode(PHP_EOL, $contenu);
 			$fp = fopen($ficEcoStationstart, 'w');
@@ -485,12 +507,12 @@ function modifLigneEcoStationstart($numligne) {
 	global $stationplan;
 	global $jourplan;
 	global $verroumodif;
-	
+
 	if($numligne!=0) {// on ne modifie pas l'entête du fichier ie la ligne 0.
 		$fp = fopen($ficEcoStationstart, 'r');
 		$contenu = fread($fp, filesize($ficEcoStationstart));
 		fclose($fp);
-		//affichage des données dans le planificateur 
+		//affichage des données dans le planificateur
 		$contenu = explode(PHP_EOL, $contenu);
 		$valligne = explode("|",$contenu[$numligne[0]]);
 		$horaireplan = $valligne[0];
@@ -534,7 +556,7 @@ function tabplanstart($fichier,$_etat) {
 	global $verroumodif;
 	global $verrouajout;
 	global $verroumodifparam;
-	
+
 	//si une programmation existe, le fichier existe
 	if(file_exists($fichier)) {
 		if(filesize($fichier) != 0) { //si le fichier n'est pas vide
@@ -550,11 +572,11 @@ function tabplanstart($fichier,$_etat) {
 				$action = 'Activer';
 			}
 			echo '<h2>Planification '.$statut.' </h2>';
-			echo '<table style="width:760px;margin-bottom:15px;">';
+			echo '<table class="tabeco">';
 			echo '<th style="text-align:center;width:25px;"></th>';
 			echo '<th style="text-align:center;width:60px;">Horaire</th>';
 			echo '<th style="text-align:center;width:165px;">Jours</th>';
-			echo '<th>Stations à démarrer</th>';
+			echo '<th style="text-align:left;">Stations à démarrer</th>';
 			echo '</tr>';
  			foreach($lignes as $ligne_num => $ligne) { // on lit le tableau de façon séquentielle
 				//on n'insère pas la ligne d'entête
@@ -618,6 +640,35 @@ function tabplanstart($fichier,$_etat) {
 function copieMachinesdb() {
 	global $chemBaseAppli;
 	system("sudo ".$chemBaseAppli."/copieFicMachinesDB.pl");
+	$fic='config/copie_machines.db';
+	$id_fichier = fopen($fic,"r");
+	$contenu = fread($id_fichier, filesize($fic));
+	fclose($id_fichier);
+
+	$json = json_decode($contenu);
+	$content = "";
+	foreach($json as $lan => $devices) {
+        	$ip = '';
+		$nom = $devices->id;
+		foreach($devices->hwaddr_interfaces as $hwdesc => $addmac){
+			if ($addmac != ":::::" && $addmac != "00:00:00:00:00:00") {
+				$mac=$addmac;
+				foreach($devices->ip4_interfaces as $ipdesc => $ipv4){
+					if ($ipdesc == $hwdesc) {
+						$ip=$ipv4[0];
+						break;
+					}
+				}
+				break;
+			}
+		}
+		if ( $ip == '' ) continue;
+		$content .= $nom.";".$ip.";".$mac."\n";
+	}
+	$id_fichier = fopen($fic,"w");
+	fwrite($id_fichier, $content);
+	fclose($id_fichier);
+
 }
 
 //lance le script qui effectue les modif sur le cron à partir du fichier de config ecoStations.txt
